==> tklib_0.8~20230222.orig.tar.gz: Tk_Library_Source_Code/embedded/index.md <==
<div class='fossil-doc' data-title='Tk Library Source Code'>

<h1 align="center">Tk Library Source Code</h1>

<center>
Packages - [Table Of Contents](md/toc.md)
&nbsp;&nbsp;&nbsp;
[Keyword Index](md/index.md)
</center>

<center>
	<form action='../../../docsrch' method='GET'>
	<input type="text" name="s" size="40" autofocus>
	<input type="submit" value="Search Package Documentation">
	</form>
</center>

A companion to Tcllib, for Tk related packages.

## Releases / Downloads

The download links are on the referenced pages.

   * [Trunk Head](head.md)
   * [Current Release](../../../event/545a7ee378a0cc271fcf58ebf83684fb4257094e) __0.7 (Feb 9, 2020)__
   * [Past Releases](../../../wiki?name=Releases)
   * [Development Snapshots](../../../wiki?name=Development+Snapshots)
   * [@ SourceForge](https://sourceforge.net/projects/tcllib/files/)

## Discussion & Contact

Tklib has two [mailing lists](https://sourceforge.net/p/tcllib/mailman/), shared with Tcllkib.

One for notifications (commits, ticket changes), the other for general
discussion. These are managed at SourceForge, at the aforementioned
link. A few direct links for various topics:

|tcllib-bugs| : |[Subscribe](https://lists.sourceforge.net/lists/listinfo/tcllib-bugs) [Archive](https://sourceforge.net/p/tcllib/mailman/tcllib-bugs) [Search](https://sourceforge.net/p/tcllib/mailman/search/?mail_list=tcllib-bugs)|
|tcllib-devel| : |[Subscribe](https://lists.sourceforge.net/lists/listinfo/tcllib-devel) [Archive](https://sourceforge.net/p/tcllib/mailman/tcllib-devel) [Search](https://sourceforge.net/p/tcllib/mailman/search/?mail_list=tcllib-devel)|

## Related Repositories

   * [Tcllib](../../../../tcllib)
   * [Tcl Apps](../../../../tclapps)
   * [Tcl Bench](../../../../tclbench)
   * [Multicolumn Listbox](../../../../mclistbox)
   * [Widget](../../../../widget)
   * [BWidget](../../../../bwidget)

## Feedback

Please go to and use our
[Local Trackers](../../../reportlist).
They are for

   * Bugs,
   * Patches, and	 
   * Ideas & Feature Requests.

## See also

   * [Landing page for this package at the Tcl Developer eXchange](http://www.tcl.tk/software/tcllib/)

==> tklib_0.9.orig.tar.gz: Tk_Library_Source_Code/embedded/index.md <==
<div class='fossil-doc' data-title='Tk Library Source Code'>

<h1 align="center">Tk Library Source Code</h1>

<center>
Packages - [Table Of Contents](md/toc.md)
&nbsp;&nbsp;&nbsp;
[Keyword Index](md/index.md)
</center>

<center>
	<form action='../../../docsrch' method='GET'>
	<input type="text" name="s" size="40" autofocus>
	<input type="submit" value="Search Package Documentation">
	</form>
</center>

A companion to Tcllib, for Tk related packages.

## Releases / Downloads

The download links are on the referenced pages.

   * [Trunk Head](head.md)
   * [Current Release](../../../technote/f6f9eed465b76f73fd066a65e4275b9552a664c7) __0.8 (Jul 6, 2024)__
   * [Past Releases](../../../wiki?name=Releases)
   * [Development Snapshots](../../../wiki?name=Development+Snapshots)
   * [@ SourceForge](https://sourceforge.net/projects/tcllib/files/)

## Discussion & Contact

Tklib has two [mailing lists](https://sourceforge.net/p/tcllib/mailman/), shared with Tcllkib.

One for notifications (commits, ticket changes), the other for general
discussion. These are managed at SourceForge, at the aforementioned
link. A few direct links for various topics:

|tcllib-bugs| : |[Subscribe](https://lists.sourceforge.net/lists/listinfo/tcllib-bugs) [Archive](https://sourceforge.net/p/tcllib/mailman/tcllib-bugs) [Search](https://sourceforge.net/p/tcllib/mailman/search/?mail_list=tcllib-bugs)|
|tcllib-devel| : |[Subscribe](https://lists.sourceforge.net/lists/listinfo/tcllib-devel) [Archive](https://sourceforge.net/p/tcllib/mailman/tcllib-devel) [Search](https://sourceforge.net/p/tcllib/mailman/search/?mail_list=tcllib-devel)|

## Related Repositories

   * [Tcllib](../../../../tcllib)
   * [Tcl Apps](../../../../tclapps)
   * [Tcl Bench](../../../../tclbench)
   * [Multicolumn Listbox](../../../../mclistbox)
   * [Widget](../../../../widget)
   * [BWidget](../../../../bwidget)

## Feedback

Please go to and use our
[Local Trackers](../../../reportlist).
They are for

   * Bugs,
   * Patches, and	 
   * Ideas & Feature Requests.

## See also

   * [Landing page for this package at the Tcl Developer eXchange](http://www.tcl.tk/software/tcllib/)
